From fb099a0b8dc1844a2141f7340db93b6adf9e0b14 Mon Sep 17 00:00:00 2001
From: Michael Vogt <mvo@debian.org>
Date: Sat, 19 Oct 2013 18:29:59 +0200
Subject: [PATCH] add Acquire::http::Proxy-Auto-Detect to the apt.conf.5
 manpage (closes: 726597)

---
 doc/apt-verbatim.ent | 6 ++++++
 doc/apt.conf.5.xml   | 8 ++++++++
 methods/http.cc      | 6 +++++-
 3 files changed, 19 insertions(+), 1 deletion(-)

diff --git a/doc/apt-verbatim.ent b/doc/apt-verbatim.ent
index c9bb061..0d0d95c 100644
--- a/doc/apt-verbatim.ent
+++ b/doc/apt-verbatim.ent
@@ -124,6 +124,12 @@
   </citerefentry>"
 >
 
+<!ENTITY squid-deb-proxy-client "<citerefentry>
+    <refentrytitle><command>squid-deb-proxy-client</command></refentrytitle>
+    <manvolnum>1</manvolnum>
+  </citerefentry>"
+>
+
 <!ENTITY debsign "<citerefentry>
     <refentrytitle><command>debsign</command></refentrytitle>
     <manvolnum>1</manvolnum>
diff --git a/doc/apt.conf.5.xml b/doc/apt.conf.5.xml
index 42119ba..e8da666 100644
--- a/doc/apt.conf.5.xml
+++ b/doc/apt.conf.5.xml
@@ -396,6 +396,14 @@ DPkg::Pre-Install-Pkgs {"/usr/sbin/dpkg-preconfigure --apt";};
      <para><literal>Acquire::http::User-Agent</literal> can be used to set a different
      User-Agent for the http download method as some proxies allow access for clients
      only if the client uses a known identifier.</para>
+
+     <para><literal>Acquire::http::Proxy-Auto-Detect</literal> can be used to
+     specify a external command to discover the http proxy to use. Apt expects
+     the command to output the proxy on stdout in the style
+     <literal>http://proxy:port/</literal>. See the 
+     &squid-deb-proxy-client; package for a example implementation that
+     uses avahi.</para>
+
      </listitem>
      </varlistentry>
 
diff --git a/methods/http.cc b/methods/http.cc
index 278ddb2..5622c33 100644
--- a/methods/http.cc
+++ b/methods/http.cc
@@ -1108,7 +1108,6 @@ bool HttpMethod::Configuration(string Message)
    PipelineDepth = _config->FindI("Acquire::http::Pipeline-Depth",
 				  PipelineDepth);
    Debug = _config->FindB("Debug::Acquire::http",false);
-   AutoDetectProxyCmd = _config->Find("Acquire::http::ProxyAutoDetect");
 
    // Get the proxy to use
    AutoDetectProxy();
@@ -1373,6 +1372,11 @@ int HttpMethod::Loop()
 /* */
 bool HttpMethod::AutoDetectProxy()
 {
+   // option is "Acquire::http::Proxy-Auto-Detect" but we allow the old
+   // name without the dash ("-")
+   AutoDetectProxyCmd = _config->Find("Acquire::http::Proxy-Auto-Detect",
+                                      _config->Find("Acquire::http::ProxyAutoDetect"));
+
    if (AutoDetectProxyCmd.empty())
       return true;
 
-- 
1.8.3.2

